#
# spec file for package beignet
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           beignet
Version:        1.3.2
Release:        6.27
Summary:        OpenCL implementation for Intel GPUs
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Url:            https://01.org/beignet/
Source0:        https://01.org/sites/default/files/%{name}-%{version}-source.tar.gz
Source99:       beignet-rpmlintrc
Patch0:         beignet-llvm6.patch
Patch1:         0008-Add-preliminary-LLVM-7-support.patch
Patch2:         beignet-disable-NegAddOptimization.patch
Patch3:         0004-Enable-Coffee-Lake-support.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  memory-constraints
BuildRequires:  ncurses-devel
BuildRequires:  opencl-headers
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(zlib)
# exclusive to Intel GPU
ExclusiveArch:  %{ix86} x86_64
%if 0%{?suse_version} > 1320
BuildRequires:  clang-devel >= 3.3
%else
BuildRequires:  llvm-clang >= 3.3
BuildRequires:  llvm-clang-devel >= 3.3
BuildRequires:  llvm-devel >= 3.3
%endif

%description
Beignet is an implementation of the OpenCL specification - a generic
compute oriented API. This code base contains the code to run OpenCL programs
on Intel GPUs, which basically defines and implements the OpenCL host functions
required to initialize the device, create the command queues, the kernels and
the programs and run them on the GPU.

%package devel
Summary:        Development files for Beignet, a OpenCL implementation for Intel GPUs
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Requires:       opencl-headers

%description devel
Devel package for Beignet, an implementation of the OpenCL
specification, a generic compute oriented API.

%prep
%setup -q -n Beignet-%{version}-Source
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
rm README.md
cp docs/Beignet.mdwn README.md

%build
%limit_build -m 2000
%cmake \
	-DLLVM_INSTALL_DIR=%{_bindir}/
%make_jobs

%install
%cmake_install
find %{buildroot}%{_includedir}/CL/ -regextype posix-egrep -not -regex ".*(cl_intel.h)" -type f -delete
rm %{buildroot}%{_libdir}/beignet/beignet*.pch

%files
%doc README.md
%license COPYING
%{_libdir}/beignet/
%{_sysconfdir}/OpenCL/vendors/intel-beignet.icd
%dir %{_sysconfdir}/OpenCL
%dir %{_sysconfdir}/OpenCL/vendors

%files devel
%doc docs/*
%{_includedir}/CL/cl_intel.h

%changelog
* Thu Jan 24 2019 alarrosa@suse.com
- Add a _constraints file to specify this package needs at least
  6500 MB of memory to build. Also use %%limit_build to be sure
  parallel builds are taken into account.
* Sat Jan 19 2019 linnaea@lavia.moe
- Add Coffee Lake support, reusing Kaby Lake code.
  * 0004-Enable-Coffee-Lake-support.patch
* Mon Jan  7 2019 linnaea@lavia.moe
- Fix build failure with llvm7 with patch from upstream Git:
  * 0008-Add-preliminary-LLVM-7-support.patch (fate#325696)
- Fix self-test failures on some systems:
  * beignet-disable-NegAddOptimization.patch
* Wed Oct 31 2018 bwiedemann@suse.com
- drop indeterministic pch files to make package build reproducible
* Wed Aug  8 2018 alarrosa@suse.com
- Add patch beignet-llvm6.patch to fix build failure with llvm6
- Fix installation of broken symlink for README.md
- Use %%license
* Wed Jan 31 2018 msrb@suse.com
- Remove dependency on clang-devel-static. (bnc#1065464)
  * It was removed, clang-devel now again provides everything
    necessary as shared libraries.
* Thu Oct 26 2017 mpluskal@suse.com
- Update to version 1.3.2:
  * Add some Gemini Lake devices support.
  * Add llvm4.0 and llvm5.0 support.
  * Add cl_intel_required_subgroup_size extension support.
  * Fix some other bugs.
- Drop no longer needed patches:
  * 0001-Backend-Remove-old-llvm-support-code.patch
  * 0002-Backend-Fix-an-include-file-error-problem.patch
  * 0003-Backend-Refine-GEP-lowering-code.patch
  * 0004-Backend-Refine-LLVM-version-check-macro.patch
  * 0005-Backend-Refine-FCmp-one-and-une.patch
  * 0006-utest-fix-image-qualifier-of-compiler_fill_gl_image-.patch
  * 0007-Backend-Add-LLVM40-support.patch
* Thu May  4 2017 mardnh@gmx.de
- Add patches for LLVM 4.0 support
  * 0001-Backend-Remove-old-llvm-support-code.patch
  * 0002-Backend-Fix-an-include-file-error-problem.patch
  * 0003-Backend-Refine-GEP-lowering-code.patch
  * 0004-Backend-Refine-LLVM-version-check-macro.patch
  * 0005-Backend-Refine-FCmp-one-and-une.patch
  * 0006-utest-fix-image-qualifier-of-compiler_fill_gl_image-.patch
  * 0007-Backend-Add-LLVM40-support.patch
* Tue Mar 14 2017 mpluskal@suse.com
- Update to version 1.3.1:
  * OpenCL 2.0 support.
  * OpenCL event and enqueue module re-implement.
  * Other OpenCL runtime driver refine.
  * LLVM 3.9 support.
  * Extension cl_khr_gl_sharing support.
  * Extension intel_subgroups_short support.
  * Large kernel compiling speed up.
  * Register allocation improvement.
  * Enable OpenCL 2.0 where device supported.
  * Optimize int64 multiply int64.
  * Add cl_khr_gl_sharing example and document.
  * Fix some bugs.
* Sun Jan  1 2017 jengelh@inai.de
- Trim filler words from description.
* Sat Nov 12 2016 mpluskal@suse.com
- Update to version 1.2.1
  * Add some Apollo Lake devices support.
  * Add llvm3.9 support.
  * Fix some cl_intel_subgroups extension bugs.
  * Avoid too many messages when the driver could not find good
    work group size.
  * Fix some other bugs.
* Tue Aug 30 2016 mardnh@gmx.de
- Update to 1.2.0
  * 6th generation Intel Atom Processors (Broxton) support.
  * 6th generation Intel Core Processors (Kabylake) support.
  * LLVM 3.7 and 3.8 support.
  * ASM debug infomation and profiling support.
  * Experimental double data type support for processors after  6th generation(Broadwell) .
  * Full cl_intel_subgroups extension.
  * OpenCL 2.0 workgroup built-in functions.
  * Local copy propagation optimization and other optimizations
  * intel_accelerator extension and basic intel_motion_estimation extension.
  * Android build.
  * Refined printf implementation.
  * Bug fixes since last release.
- Drop no longer needed patches (fixed upstream)
  * gcc6-support.patch
  * llvm38-support.patch
  * std-isnan-isinf.patch
* Mon Jul  4 2016 mardnh@gmx.de
- Add patches to support build with GCC6.1
  * gcc6-support.patch
  * llvm38-support.patch
  * std-isnan-isinf.patch
* Sun May  8 2016 mpluskal@suse.com
- Update to 1.1.2
  * Add Broxton support.
  * Add llvm3.7 support.
  * Fix event bugs.
  * Fix the annoying "Failed to release userptr..." error message.
  * Fix printf bugs.
- Drop no longer needed beignet-llvm37.diff
* Fri Dec 18 2015 mpluskal@suse.com
- Update to 1.1.1
  * Dump asm to a file.
  * Use addRemappedFile to avoid creating temporary cl source file.
  * add collectInsnNum to collect block instruction number.
  * Fix piglit clLinkProgram fail.
  * Calculate appropriate timestamps for cl profile.
- Use cmake macros
* Thu Oct 22 2015 normand@linux.vnet.ibm.com
- add ExclusiveArch %%{ix86} x86_64 to avoid build error other archi
* Tue Oct 13 2015 mardnh@gmx.de
- add patch: beignet-llvm37.diff to support llvm 3.7
- add rpmlintrc
* Fri Jul 31 2015 mardnh@gmx.de
- update to version 1.1.0
  The highlighted improvements are as below:
  * Added 6th generation Intel Core Processors (SKL) support.
  * Added 5th generation Intel Atom Processors (BSW) support.
  * Re-implement structurized control flow algorithm.
  * Added half data type support after BDW.
  * Implement a new BTI solution to support dynamic bti.
  * Added extension cl_intel_subgroups support.
  * Replace some built-ins with llvm intrinsic.
  * Add Indirect structure argument read support.
  * Enable cl_khr_spir extension to build and run from SPIR binary.
  * Improvement some opencv test suite performance on all platforms.
  * Several other bug fixes since last release.
- removed patch beignet-icd-name-fix.diff (included upstream)
* Tue Mar 17 2015 mardnh@gmx.de
- update to version 1.0.2
  It's a bug fix release including some bug fixes, minor new
  features and some performance improvements.
  The highlighted improvements are as below:
  * Added LLVM 3.6 support.
  * Fixed a bug in popcount().
  * Refactor the legalize pass and const expression handling.
  * Fixed a bug when hardware is inaccessible.
  * Enabled multiarch 32bit and 64bit coexisting.
  * Implemented some new device side clCopyImage kernels.
  * Optimize clEnqueueCopyImageToBuffer for 16 aligned buffer.
* Mon Jan 19 2015 mardnh@gmx.de
- update to version 1.0.1
  * Enable userptr support by default thus it's possible to achieve zero-copy
  when create a buffer object.
  * Change to use TILING_Y mode on BDW platform which lead to a major performance
  improvement for some cases.
  * Fix one liveness bug which is the last such type of known bug in the
  Gen Backend.
  * Fix some builtin math function's accuracy bugs.
  * Improve the strict mode sin/cos implementation, reduce the instruction count
  from 1700 to 400.
  * Use Clang native sampler and image types, now image/sampler are fully comply
  with OpenCL spec.
  * Fix bugs triggered by some popular applications such as darktable.
  Now darktable works fine on all the supported platforms.
  * Add support for old system which doesn't have c++11 features.
* Sat Nov 15 2014 mardnh@gmx.de
- update to version 1.0.0
- removed patch fix_no-return-in-nonvoid-function-llvm_gen_backend.diff
  since it is now included upstream
* Sat Oct 18 2014 mardnh@gmx.de
- added patch: fix_no-return-in-nonvoid-function-llvm_gen_backend.diff
  to address a build rpm-post build error
  - -----------------------------------------
  E: beignet no-return-in-nonvoid-function
  backend/src/llvm/llvm_gen_backend.cpp:1108
  - -----------------------------------------
- add ncurses-devel to BuildRequires
- added build flags CMAKE_BUILD_TYPE=Release
* Tue Oct  7 2014 mardnh@gmx.de
- initial stable package, version 0.9.3
  based on home:mnhauke:opencl:testing/beignet
